@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 # Copyright © 2019 Dr. Tobias Quathamer <toddy@debian.org>
-#           © 2022 Dr. Helge Kreutzmann <debian@helgefjell.de>
+#           © 2022,2023 Dr. Helge Kreutzmann <debian@helgefjell.de>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -42,19 +42,24 @@ fi
 
 # Necessary, size 0 file of mktemp fails for UTF-8 characters, see Debian bug #1022216
 tdir=$(mktemp -d)
+mkdir $tdir/$distribution
+
+# Remove / Uncomment some macros po4a cannot handle
+# The last two can be removed, if mkpasswd (Debian BTS #1036908) and gawk (reported upstream) are fixed (or Debian #1036826)
+cat $upstream_manpage | sed "s/^.ft C$/^\".ft C$/" | sed "s/^.ft P$/^\".ft P$/" | sed "s/\\\\fb/\\fB/" | sed "s/^\.BI \(\\\\.*\)\"\\\\c$/.BI \1\"/" | sed "s/^\.BR \(\\\\.*\)\"\\\\c$/.BI \1\"/" > $tdir/$distribution/$manpage
 
 po4a-updatepo -f man \
         --no-deprecation \
 	--option groff_code=verbatim \
 	--option generated \
-	--option untranslated="a.RE,\|" \
+	--option untranslated="}1,Ds,zY,zZ,Ee,ES,dT,rstReportMargin,INDENT,UNINDENT,UN,a.RE,\|" \
 	--option unknown_macros=untranslated \
-	--master "$upstream_manpage" -M utf-8 \
+	--master "$tdir/$distribution/$manpage" -M utf-8 \
 	-p $tdir/tmp.pot
 
 # Reduce the location lines from the full path and line number
 # to the name of the distribution
-cat $tdir/tmp.pot | sed -e "s,^#: ../upstream/\([^/]\+\)/man.*$,#: \1," |\
+cat $tdir/tmp.pot | sed -e "s,^#: /tmp/tmp\.[a-zA-Z0-9]*/\([^/]\+\)/.*,#: \1," |\
 	# Ensure the correct encoding is set
 	sed -e "s/^\"Content-Type: text\/plain; charset=CHARSET\\\\n\"$/\"Content-Type: text\/plain; charset=UTF-8\\\\n\"/"
 
